@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use 5.10.0;
 
-use Mojo::JSON;
+use Mojo::JSON                      qw(decode_json);
 use Digest::MD5                     qw(md5_hex);
 use Encode                          qw(encode_utf8);
 
@@ -23,7 +23,6 @@ Parse address from string
 sub parse {
     my ($class, $str) = @_;
 
-    return undef unless defined $str;
     my ($full, $address, $lon, $lat, $md5, $id, $type, $lang, $opt);
 
     if( $str =~ m{^\s*\[} and $str =~ m{\]\s*$} ) {
@@ -34,13 +33,7 @@ sub parse {
         eval { utf8::encode $str }    if utf8::is_utf8 $str;
 
         # Try parse
-        my $json = eval{
-            if( version->new($Mojolicious::VERSION) < version->new(5.54) ) {
-                return Mojo::JSON->new->decode( $str );
-            } else {
-                return Mojo::JSON::decode_json( $str );
-            }
-        };
+        my $json = eval{ decode_json $str; };
         if( not $@ and $json and 'ARRAY' eq ref($json)) {
             $full       = sprintf '%s : %s , %s',
                             $json->[2]//'', $json->[3]//'', $json->[4]//'';
@@ -130,12 +123,12 @@ sub near {
 
 1;
 
-=head1 AUTHORS
+=AUTHORS
 
 Dmitry E. Oboukhov <unera@debian.org>
 Roman V. Nikolaev <rshadow@rambler.ru>
 
-=head1 COPYRIGHT
+=COPYRIGHT
 
 Copyright (C) 2011 Dmitry E. Oboukhov <unera@debian.org>
 Copyright (C) 2011 Roman V. Nikolaev <rshadow@rambler.ru>
